@@ -9,7 +9,7 @@ frag <- calcAdjFrag(ieegts, 20, 10, nSearch = 2)
 
 test_that("fragStat", {
   skip_if(!is(frag, "Fragility"))
-  stat <- fragStat(frag = frag, sozIndex = elecSoz) |> expect_no_error()
+  stat <- fragStat(frag = frag, groupIndex = elecSoz) |> expect_no_error()
   expect_s4_class(stat, "FragStat")
   ## Test the show method
   print(stat) |>  capture.output() |> expect_no_error()
