@@ -5,10 +5,6 @@ displayIndexOutOfRange <- 77:85
 str <- rownames(pt01EcoG)[displayIndex]
 strError <- c(str, "Whatever")
 
-test_that("visuIEEGData", { 
-  visuIEEGData(pt01EcoG) |> expect_no_error()
-})
-
 test_that("plotFragHeatmap", {
   plotFragHeatmap(pt01Frag, displayIndex)           |> expect_no_error()
   plotFragHeatmap(pt01Frag, displayIndexOutOfRange) |> expect_warning()
